==> jc-1.4.0.tar.gz: soot/shimple/internal/OneHeadBlockGraph.c <==
// public class soot.shimple.internal.OneHeadBlockGraph

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class be56ff673eefd9d2 java_util_Iterator
// @dep_class 9ee0d92ce1525a4d java_util_List
// @dep_class ddd7609e6ca992af soot_shimple_internal_HeadBlock
// @dep_class 5ff4b4cec1ffbbcb soot_shimple_internal_OneHeadBlockGraph
// @dep_class b252d9c4153bf27b soot_toolkits_graph_Block
// @dep_class 340ee84e9e1f189d soot_toolkits_graph_BlockGraph

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Iterator
// @dep_header java_util_List
// @dep_header soot_shimple_internal_HeadBlock
// @dep_header soot_shimple_internal_OneHeadBlockGraph
// @dep_header soot_toolkits_graph_BlockGraph

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Iterator.h"
#include "java/util/List.h"
#include "soot/shimple/internal/HeadBlock.h"
#include "soot/shimple/internal/OneHeadBlockGraph.h"
#include "soot/toolkits/graph/BlockGraph.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static void convert(soot.toolkits.graph.BlockGraph)
//

static _jc_linenum _jc_soot_shimple_internal_OneHeadBlockGraph$linenum_table$convert$1e4e5b4571f54a82[];

static const unsigned char _jc_soot_shimple_internal_OneHeadBlockGraph$param_ptypes$convert$1e4e5b4571f54a82[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_shimple_internal_OneHeadBlockGraph$param_types$convert$1e4e5b4571f54a82[] = {
	&_jc_soot_toolkits_graph_BlockGraph$type
};

_jc_method _jc_soot_shimple_internal_OneHeadBlockGraph$method_info$convert$1e4e5b4571f54a82 = {
	.name=			"convert",
	.signature=		"(Lsoot/toolkits/graph/BlockGraph;)V",
	.class=			&_jc_soot_shimple_internal_OneHeadBlockGraph$type,
	.param_types=		&_jc_soot_shimple_internal_OneHeadBlockGraph$param_types$convert$1e4e5b4571f54a82,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_shimple_internal_OneHeadBlockGraph$param_ptypes$convert$1e4e5b4571f54a82,
	.signature_hash=	_JC_JLONG(0x1e4e5b4571f54a82),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_soot_shimple_internal_OneHeadBlockGraph$method$convert$1e4e5b4571f54a82,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	11,
	      .table=	_jc_soot_shimple_internal_OneHeadBlockGraph$linenum_table$convert$1e4e5b4571f54a82
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_shimple_internal_OneHeadBlockGraph, convert$1e4e5b4571f54a82);

void
_jc_soot_shimple_internal_OneHeadBlockGraph$method$convert$1e4e5b4571f54a82(_jc_env *const env, _jc_soot_toolkits_graph_BlockGraph$object *param0)
{
	jint i0;
	struct _jc_soot_toolkits_graph_BlockGraph$object *r0;
	struct _jc_object *r1;
	struct _jc_object *r2;
	struct _jc_soot_shimple_internal_HeadBlock$object *r3;
	struct _jc_object *r4;
	struct _jc_soot_toolkits_graph_Block$object *r5;
	struct _jc_java_lang_Object$object *r7;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = param0;
	_JC_LINE_NUMBER(42);				// 0
	r1 = _JC_INVOKE_VIRTUAL(env, soot_toolkits_graph_BlockGraph, getHeads$e2893bcf27fe8f99, r0);
	_JC_LINE_NUMBER(43);				// 1
	r2 = _JC_INVOKE_VIRTUAL(env, soot_toolkits_graph_BlockGraph, getBlocks$e4cd93cc80f2dcae, r0);
	_JC_LINE_NUMBER(45);				// 2
	i0 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x345df5220fc60ade), jint);
	if (i0 <= 1)
		goto label2;
	_JC_LINE_NUMBER(46);				// 3
	r3 = _JC_NEW(env, soot_shimple_internal_HeadBlock);
	_JC_INVOKE_NONVIRTUAL(env, soot_shimple_internal_HeadBlock, _init$dd8ff073a2c7f994, 0, r3, r1);
	_JC_LINE_NUMBER(47);				// 4
	_JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xa5acde3ee27a066), void);
	_JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x831f06ee5f59c0cc), jboolean, r3);
	_JC_LINE_NUMBER(51);				// 5
	r4 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x3cc91493d50f531c), _jc_object *);

label0:
	_JC_LINE_NUMBER(52);				// 6
	z1 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0xfb0bd5e38c59ddcd), jboolean);
	if (z1 == 0)
		goto label1;
	_JC_LINE_NUMBER(53);				// 7
	r7 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0x5874f79a1cf66ea), _jc_object *);
	r5 = _JC_CAST(env, &_jc_soot_toolkits_graph_Block$type, r7);
	_JC_LINE_NUMBER(54);				// 8
	i0 = _JC_INVOKE_VIRTUAL(env, soot_toolkits_graph_Block, getIndexInMethod$6a81610f7fcf3d74, r5);
	i0 = i0 + 1;
	_JC_INVOKE_VIRTUAL(env, soot_toolkits_graph_Block, setIndexInMethod$2720e755cea1f11e, r5, i0);
	_JC_PERIODIC_CHECK(env);
	goto label0;

label1:
	_JC_LINE_NUMBER(58);				// 9
	_JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x9953f092f36e3303), void, 0, r3);

label2:
	_JC_LINE_NUMBER(60);				// 10
	return;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_shimple_internal_OneHeadBlockGraph$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_shimple_internal_OneHeadBlockGraph$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_shimple_internal_OneHeadBlockGraph$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_shimple_internal_OneHeadBlockGraph$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_shimple_internal_OneHeadBlockGraph$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_shimple_internal_OneHeadBlockGraph$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_shimple_internal_OneHeadBlockGraph$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_shimple_internal_OneHeadBlockGraph, _init$52f4ad9f2989aeee);

void
_jc_soot_shimple_internal_OneHeadBlockGraph$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_shimple_internal_OneHeadBlockGraph$object *this)
{
	struct _jc_soot_shimple_internal_OneHeadBlockGraph$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(34);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_shimple_internal_OneHeadBlockGraph$methods[] = {
	&_jc_soot_shimple_internal_OneHeadBlockGraph$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_shimple_internal_OneHeadBlockGraph$method_info$convert$1e4e5b4571f54a82
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_bucket_75[] = {
	&_jc_soot_shimple_internal_OneHeadBlockGraph$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[75]=	_jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_bucket_75,
	[113]=	_jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_shimple_internal_OneHeadBlockGraph$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Iterator",	_JC_JLONG(0xbe56ff673eefd9d2) },
	{ "java/util/List",	_JC_JLONG(0x9ee0d92ce1525a4d) },
	{ "soot/shimple/internal/HeadBlock",	_JC_JLONG(0xddd7609e6ca992af) },
	{ "soot/toolkits/graph/Block",	_JC_JLONG(0xb252d9c4153bf27b) },
	{ "soot/toolkits/graph/BlockGraph",	_JC_JLONG(0x340ee84e9e1f189d) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_shimple_internal_OneHeadBlockGraph$vtype _jc_soot_shimple_internal_OneHeadBlockGraph$type = {
    .type= {
	.name=			"soot/shimple/internal/OneHeadBlockGraph",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x5ff4b4cec1ffbbcb),
		.source_file=		"OneHeadBlockGraph.java",
		.instance_size=		sizeof(_jc_soot_shimple_internal_OneHeadBlockGraph$refs) + sizeof(_jc_soot_shimple_internal_OneHeadBlockGraph$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_shimple_internal_OneHeadBlockGraph$methods) / sizeof(*_jc_soot_shimple_internal_OneHeadBlockGraph$methods),
		.methods=		_jc_soot_shimple_internal_OneHeadBlockGraph$methods,
		.instanceof_hash_table=	_jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_shimple_internal_OneHeadBlockGraph$class_depends) / sizeof(*_jc_soot_shimple_internal_OneHeadBlockGraph$class_depends),
		.class_depends=		_jc_soot_shimple_internal_OneHeadBlockGraph$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_shimple_internal_OneHeadBlockGraph= {
	},
    }
};

==> jc-1.4.5.tar.gz: soot/shimple/internal/OneHeadBlockGraph.c <==
// public class soot.shimple.internal.OneHeadBlockGraph

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class be56ff673eefd9d2 java_util_Iterator
// @dep_class 9ee0d92ce1525a4d java_util_List
// @dep_class ddd7609e6ca992af soot_shimple_internal_HeadBlock
// @dep_class 5ff4b4cec1ffbbcb soot_shimple_internal_OneHeadBlockGraph
// @dep_class b252d9c4153bf27b soot_toolkits_graph_Block
// @dep_class 340ee84e9e1f189d soot_toolkits_graph_BlockGraph

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Iterator
// @dep_header java_util_List
// @dep_header soot_shimple_internal_HeadBlock
// @dep_header soot_shimple_internal_OneHeadBlockGraph
// @dep_header soot_toolkits_graph_BlockGraph

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Iterator.h"
#include "java/util/List.h"
#include "soot/shimple/internal/HeadBlock.h"
#include "soot/shimple/internal/OneHeadBlockGraph.h"
#include "soot/toolkits/graph/BlockGraph.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static void convert(soot.toolkits.graph.BlockGraph)
//

static _jc_linenum _jc_soot_shimple_internal_OneHeadBlockGraph$linenum_table$convert$1e4e5b4571f54a82[];

static const unsigned char _jc_soot_shimple_internal_OneHeadBlockGraph$param_ptypes$convert$1e4e5b4571f54a82[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_shimple_internal_OneHeadBlockGraph$param_types$convert$1e4e5b4571f54a82[] = {
	&_jc_soot_toolkits_graph_BlockGraph$type
};

_jc_method _jc_soot_shimple_internal_OneHeadBlockGraph$method_info$convert$1e4e5b4571f54a82 = {
	.name=			"convert",
	.signature=		"(Lsoot/toolkits/graph/BlockGraph;)V",
	.class=			&_jc_soot_shimple_internal_OneHeadBlockGraph$type,
	.param_types=		&_jc_soot_shimple_internal_OneHeadBlockGraph$param_types$convert$1e4e5b4571f54a82,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_shimple_internal_OneHeadBlockGraph$param_ptypes$convert$1e4e5b4571f54a82,
	.signature_hash=	_JC_JLONG(0x1e4e5b4571f54a82),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_soot_shimple_internal_OneHeadBlockGraph$method$convert$1e4e5b4571f54a82,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	11,
	      .table=	_jc_soot_shimple_internal_OneHeadBlockGraph$linenum_table$convert$1e4e5b4571f54a82
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_shimple_internal_OneHeadBlockGraph, convert$1e4e5b4571f54a82);

void _JC_JCNI_ATTR
_jc_soot_shimple_internal_OneHeadBlockGraph$method$convert$1e4e5b4571f54a82(_jc_env *const env, _jc_soot_toolkits_graph_BlockGraph$object *param0)
{
	jint i0;
	struct _jc_soot_toolkits_graph_BlockGraph$object *r0;
	struct _jc_object *r1;
	struct _jc_object *r2;
	struct _jc_soot_shimple_internal_HeadBlock$object *r3;
	struct _jc_object *r4;
	struct _jc_soot_toolkits_graph_Block$object *r5;
	struct _jc_java_lang_Object$object *r7;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = param0;
	_JC_LINE_NUMBER(42);				// 0
	r1 = _JC_INVOKE_VIRTUAL(env, soot_toolkits_graph_BlockGraph, getHeads$e2893bcf27fe8f99, r0);
	_JC_LINE_NUMBER(43);				// 1
	r2 = _JC_INVOKE_VIRTUAL(env, soot_toolkits_graph_BlockGraph, getBlocks$e4cd93cc80f2dcae, r0);
	_JC_LINE_NUMBER(45);				// 2
	i0 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x345df5220fc60ade), jint, (_jc_env *, struct _jc_object *));
	if (i0 <= 1)
		goto label2;
	_JC_LINE_NUMBER(46);				// 3
	r3 = _JC_NEW(env, soot_shimple_internal_HeadBlock);
	_JC_INVOKE_NONVIRTUAL(env, soot_shimple_internal_HeadBlock, _init$dd8ff073a2c7f994, 0, r3, r1);
	_JC_LINE_NUMBER(47);				// 4
	_JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xa5acde3ee27a066), void, (_jc_env *, struct _jc_object *));
	_JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x831f06ee5f59c0cc), jboolean, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *), r3);
	_JC_LINE_NUMBER(51);				// 5
	r4 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x3cc91493d50f531c), _jc_object *, (_jc_env *, struct _jc_object *));

label0:
	_JC_LINE_NUMBER(52);				// 6
	z1 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0xfb0bd5e38c59ddcd), jboolean, (_jc_env *, struct _jc_object *));
	if (z1 == 0)
		goto label1;
	_JC_LINE_NUMBER(53);				// 7
	r7 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0x5874f79a1cf66ea), _jc_object *, (_jc_env *, struct _jc_object *));
	r5 = _JC_CAST(env, &_jc_soot_toolkits_graph_Block$type, r7);
	_JC_LINE_NUMBER(54);				// 8
	i0 = _JC_INVOKE_VIRTUAL(env, soot_toolkits_graph_Block, getIndexInMethod$6a81610f7fcf3d74, r5);
	i0 = i0 + 1;
	_JC_INVOKE_VIRTUAL(env, soot_toolkits_graph_Block, setIndexInMethod$2720e755cea1f11e, r5, i0);
	_JC_PERIODIC_CHECK(env);
	goto label0;

label1:
	_JC_LINE_NUMBER(58);				// 9
	_JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x9953f092f36e3303), void, (_jc_env *, struct _jc_object *, jint, struct _jc_java_lang_Object$object *), 0, r3);

label2:
	_JC_LINE_NUMBER(60);				// 10
	return;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_shimple_internal_OneHeadBlockGraph$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_shimple_internal_OneHeadBlockGraph$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_shimple_internal_OneHeadBlockGraph$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_shimple_internal_OneHeadBlockGraph$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_shimple_internal_OneHeadBlockGraph$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_shimple_internal_OneHeadBlockGraph$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_shimple_internal_OneHeadBlockGraph$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_shimple_internal_OneHeadBlockGraph, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_shimple_internal_OneHeadBlockGraph$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_shimple_internal_OneHeadBlockGraph$object *this)
{
	struct _jc_soot_shimple_internal_OneHeadBlockGraph$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(34);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_shimple_internal_OneHeadBlockGraph$methods[] = {
	&_jc_soot_shimple_internal_OneHeadBlockGraph$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_shimple_internal_OneHeadBlockGraph$method_info$convert$1e4e5b4571f54a82
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_bucket_75[] = {
	&_jc_soot_shimple_internal_OneHeadBlockGraph$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[75]=	_jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_bucket_75,
	[101]=	_jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_shimple_internal_OneHeadBlockGraph$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Iterator",	_JC_JLONG(0xbe56ff673eefd9d2) },
	{ "java/util/List",	_JC_JLONG(0x9ee0d92ce1525a4d) },
	{ "soot/shimple/internal/HeadBlock",	_JC_JLONG(0xddd7609e6ca992af) },
	{ "soot/toolkits/graph/Block",	_JC_JLONG(0xb252d9c4153bf27b) },
	{ "soot/toolkits/graph/BlockGraph",	_JC_JLONG(0x340ee84e9e1f189d) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_shimple_internal_OneHeadBlockGraph$vtype _jc_soot_shimple_internal_OneHeadBlockGraph$type = {
    .type= {
	.name=			"soot/shimple/internal/OneHeadBlockGraph",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x5ff4b4cec1ffbbcb),
		.source_file=		"OneHeadBlockGraph.java",
		.instance_size=		sizeof(_jc_soot_shimple_internal_OneHeadBlockGraph$refs) + sizeof(_jc_soot_shimple_internal_OneHeadBlockGraph$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_shimple_internal_OneHeadBlockGraph$methods) / sizeof(*_jc_soot_shimple_internal_OneHeadBlockGraph$methods),
		.methods=		_jc_soot_shimple_internal_OneHeadBlockGraph$methods,
		.instanceof_hash_table=	_jc_soot_shimple_internal_OneHeadBlockGraph$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_shimple_internal_OneHeadBlockGraph$class_depends) / sizeof(*_jc_soot_shimple_internal_OneHeadBlockGraph$class_depends),
		.class_depends=		_jc_soot_shimple_internal_OneHeadBlockGraph$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_shimple_internal_OneHeadBlockGraph= {
	},
    }
};
